@@ -64,8 +64,8 @@ test_that(
     expect_is(gz_out$LON, "numeric")
     expect_is(gz_out$ELEV_M, "numeric")
     expect_is(gz_out$ELEV_M_SRTM_90m, "numeric")
-    expect_is(gz_out$BEGIN, "numeric")
-    expect_is(gz_out$END, "numeric")
+    expect_is(gz_out$BEGIN, "integer")
+    expect_is(gz_out$END, "integer")
     expect_is(gz_out$YEARMODA, "Date")
     expect_is(gz_out$YEAR, "character")
     expect_is(gz_out$MONTH, "character")
